<?php

/*
 * stats-country.php
$Id: stats-country.php 1502 2010-10-05 07:04:02Z admin $
*/

// Require the initialisation file
require_once '../../init.php';

// Required files
require_once MAX_PATH . '/www/admin/config.php';
require_once MAX_PATH . '/www/admin/lib-statistics.inc.php';
require_once MAX_PATH . '/lib/max/other/common.php';
require_once MAX_PATH . '/lib/max/Admin_DA.php';
require_once MAX_PATH . '/lib/max/other/html.php';
require_once MAX_PATH . '/lib/max/other/stats.php';
require_once MAX_PATH . '/lib/pear/Date.php';

// Security check
OA_Permission::enforceAccount(OA_ACCOUNT_MANAGER, OA_ACCOUNT_ADVERTISER, OA_ACCOUNT_TRAFFICKER);

// Get input variables
$pref = $GLOBALS['_MAX']['PREF'];
$hideinactive   = MAX_getStoredValue('hideinactive', ($pref['ui_hide_inactive'] == true), null, true);
$listorder      = MAX_getStoredValue('listorder', 'date_time');
$orderdirection = MAX_getStoredValue('orderdirection', 'up');
$aNodes         = MAX_getStoredArray('nodes', array());
$day            = MAX_getStoredValue('day', null, 'stats-country.php');
$howLong        = MAX_getStoredValue('howLong', 'd');
$hour           = MAX_getStoredValue('hour', null, 'stats-country.php', true);

if (!empty($day)) {
    // Reset period
    $period_preset = '';
    // Always refresh howLong and hour
    $howLong = MAX_getValue('howLong', 'd');
    $hour    = MAX_getValue('hour');
} else {
    $period_preset  = MAX_getStoredValue('period_preset', 'today');
    $period_start   = MAX_getStoredValue('period_start', date('Y-m-d'));
    $period_end     = MAX_getStoredValue('period_end', date('Y-m-d'));
}

if (is_numeric($hour) && $hour < 10 && strlen($hour) != 2) {
    $hour = '0' . $hour;
}

$expand         = MAX_getValue('expand', '');
$collapse       = MAX_getValue('collapse');

$clientId       = MAX_getValue('clientid');
$campaignId     = MAX_getValue('campaignid');
$bannerId       = MAX_getValue('bannerid');

$affiliateId    = MAX_getValue('affiliateid');
$zoneId         = MAX_getValue('zoneid');

if (OA_Permission::isAccount(OA_ACCOUNT_ADVERTISER)) {
    $clientId = $clientid = OA_Permission::getEntityId();
} elseif (OA_Permission::isAccount(OA_ACCOUNT_TRAFFICKER)) {
    $affiliateId = $affiliateid = OA_Permission::getEntityId();
}

// Build $addUrl variable which will be added to any required link on this page
$entityIds = array(
    'entity'      => 'country',
    'clientid'    => $clientid,
    'campaignid'  => $campaignId,
    'bannerid'    => $bannerId,
    'affiliateid' => $affiliateId,
    'zoneid'      => $zoneId,
);
$addUrl = "entity=country&clientid=$clientId&campaignid=$campaignId&bannerid=$bannerId&affiliateid=$affiliateId&zoneid=$zoneId";

if (!empty($day)) {
    $entityIds += array(
        'day' => $day,
        'hour' => $hour,
        'howLong' => $howLong
    );
    $addUrl .= "&day={$day}&hour={$hour}&howLong={$howLong}";
} else {
    $entityIds += array(
        'period_preset' => $period_preset,
        'period_start' => $period_start,
        'period_end' => $period_end,
    );
    $addUrl .= "&period_preset={$period_preset}&period_start={$period_start}&period_end={$period_end}";
}
// Adjust which nodes are opened closed...
MAX_adjustNodes($aNodes, $expand, $collapse);

// Display navigation
if(OA_Permission::isAccount(OA_ACCOUNT_TRAFFICKER)) {
    // Navigation for publisher
    $conf = &$GLOBALS['_MAX']['CONF'];
    $affiliateid = OA_Permission::getEntityId();

    phpAds_PageHeader("1.1");
    echo '<br><br>';
} elseif(OA_Permission::isAccount(OA_ACCOUNT_ADVERTISER)) {
    // Navigation for advertiser
    $clientid = OA_Permission::getEntityId();

    phpAds_PageHeader("1.1");
    echo '<br><br>';
} else {
    // Navigation for admin and agency

    phpAds_PageHeader("2.1");
    echo '<br><br>';
}
// Initialise some parameters
$pageName = basename($_SERVER['PHP_SELF']);
$tabindex = 1;
$advertisersHidden = 0;

// Display date filter form
if(empty($day)) {
    $aDates = MAX_getDatesByPeriod($period_preset, $period_start, $period_end);
} else {
    $aDates = array();
    $oDayDate = new Date();
    $oDayDate->setDate($day, DATE_FORMAT_TIMESTAMP);
    if(!empty($hour)) {
        // If hour is set build day date including hour
        $aDates['day_hour'] = $oDayDate->format('%Y-%m-%d').' '.$hour;
    } else {
        // Build month, day, day_begin and day_end dependends on $howLong
        switch($howLong) {
            case 'm':
                $aDates['month'] = $oDayDate->format('%Y-%m');
                break;
            case 'w':
                $aDates['day_begin'] = $oDayDate->format('%Y-%m-%d');
                $oDayDate->addSeconds(60*60*24*7); // Add 7 days
                $aDates['day_end'] = $oDayDate->format('%Y-%m-%d');
                break;
            case 'd':
            default:
                $aDates['day'] = $oDayDate->format('%Y-%m-%d');
                break;
        }
    }
}

$hiddenValues = array(
    'entity'   => 'country',
    'clientid' => $clientId,
    'campaignid' => $campaignId,
    'bannerid' => $bannerId,
    'affiliateid' => $affiliateId,
    'zoneid' => $zoneId,
);
if(!empty($period_preset)) {
    MAX_displayDateSelectionForm($period_preset, $period_start, $period_end, $pageName, $tabindex, $hiddenValues);
} else {
    $comma = '';
    foreach($aDates as $dateValue) {
        echo $comma.$dateValue;
        $comma = ' - ';
    }
}

phpAds_ShowBreak();

$aParams = array();
$aParams['agency_id'] = OA_Permission::getAgencyId();

$aParams['clientid']    = $clientId;
$aParams['campaignid']  = $campaignId;
$aParams['bannerid']    = $bannerId;
$aZonesIds = null; // Admin_DA class expects null if no zones to be used
if (empty($zoneId) && !empty($affiliateId)) {
    $aZonesIds = Admin_DA::fromCache('getZonesIdsByAffiliateId', $affiliateId);
}
if(!empty($zoneId)) {
    $aZonesIds = array($zoneId);
}
$aParams['zonesIds'] = $aZonesIds;
//$aParams['listorder'] = $listorder;
//$aParams['orderdirection'] = $orderdirection;



// Get countries...

if (  !empty($GLOBALS['_MAX']['CONF']['plugins']['openXDeliveryLogCountry']) &&
      !empty($GLOBALS['_MAX']['CONF']['pluginGroupComponents']['oxLogCountry'])) {

    $aCountries = Admin_DA::fromCache('getCountries', $aParams + $aDates);

} else {
    // no plugin, no stats :-)
    $aCountries = array();
}

// Build the country array
if (!empty($aCountries)) {
    $pref = $GLOBALS['_MAX']['PREF'];
    $countrynames = array();
    require MAX_PATH.'/plugins/deliveryLimitations/Geo/data/res-iso3166.inc.php';
    foreach ($OA_Geo_ISO3166 as $k => $v) {
        if (!in_array($k, $OA_Geo_ISO3166_Deprecated) && !in_array($k, $OA_Geo_ISO3166_MaxMind)) {
            $countrynames[$k] = $v;
        }
    }
    foreach ($OA_Geo_ISO3166_MaxMind as $k => $v) {
        $countrynames[$k] = $v;
    }

    echo "
        <br /><br />
        <table border='0' width='100%' cellpadding='0' cellspacing='0' class='table'>";

    $column1 = _scGetHtmlHeaderColumn($GLOBALS['strCountry'], 'country', $pageName, $entityIds, $listorder, $orderdirection);
    $column2 = _scGetHtmlHeaderColumn($GLOBALS['strName'], 'name', $pageName, $entityIds, $listorder, $orderdirection);
    $column3 = _scGetHtmlHeaderColumn($GLOBALS['strImpressions'], 'impressions', $pageName, $entityIds, $listorder, $orderdirection);
    $column4 = _scGetHtmlHeaderColumn($GLOBALS['strClicks'], 'clicks', $pageName, $entityIds, $listorder, $orderdirection);
    $column5 = _scGetHtmlHeaderColumn($GLOBALS['strCTRShort'], 'ctr', $pageName, $entityIds, $listorder, $orderdirection);

    echo "
        <tr class='last'>
            <td class='aleft' style='padding: 0 4px'>&nbsp;&nbsp;$column1</td>
            <td class='aleft' style='padding: 0 4px'>&nbsp;&nbsp;$column2</td>
            <td class='aright' style='padding: 0 4px'>$column3</td>
            <td class='aright' style='padding: 0 4px'>$column4</td>
            <td class='aright' style='padding: 0 4px'>$column5</td>
        </tr>";

    // add columns for sorting
    foreach($aCountries as $country => $row) {
        $aCountries[$country]['name'] = array_key_exists($country, $countrynames) ? $countrynames[$country] : '';
        $aCountries[$country]['ctr'] = $row['impressions']  ? 100 * $row['clicks'] / $row['impressions'] : 0;
    }
    $total_countries = 0;
    $total_impressions = 0;
    $total_clicks = 0;
    
    // Variable to determine if the row should be grey or white...
    $i=0;

    // Column sorting
    if ($listorder == 'country') {
        if ($orderdirection == 'up') {
            ; // standard sort order
        } else {
            $aCountries = array_reverse($aCountries, true);
        }
    } else {
        switch($listorder) {
            case 'name':
            case 'impressions':
            default:
                MAX_sortArray($aCountries, $listorder, $orderdirection == 'up');
                break;
            case 'ctr':
                uasort($aCountries, 'numeric_cmp_ctr');
                if ($orderdirection != 'up') {
                    $aCountries = array_reverse($aCountries, true);
                }
                break;
        }
    }

    // Loop through countries
    foreach($aCountries as $country => $row) {
        $cls = ($i++ % 2 == 0) ? 'dark' : 'light';
        if ($country == '') {
            $country = '-';
        }

        echo "<tr height='25' class='{$cls}'>
            <td class='{$cls} aleft'>{$country}</td>
            <td class='{$cls} aleft'>{$row['name']}</td>
            <td class='{$cls} aright'>{$row['impressions']}</td>
            <td class='{$cls} aright'>{$row['clicks']}</td>
            <td class='{$cls} aright'>".($row['ctr'] ? "<acronym title='{$row['ctr']}%'>".number_format($row['ctr'], $pref['ui_percentage_decimals'])."%</acronym>" : '-')."</td>
        </tr>";

        $total_countries++;
        $total_impressions += $row['impressions'];
        $total_clicks += $row['clicks'];

    }
    $i++;
    echo "
        <tr height='1' class='last'><td colspan='3'></td></tr>
        <tr height='25'$bgcolor>
          <td class='{$cls} aleft'>{$strTotal}</td>
          <td class='{$cls} aleft'>{$total_countries}</td>
          <td class='{$cls} aright'>{$total_impressions}</td>
          <td class='{$cls} aright'>{$total_clicks}</td>
          <td class='{$cls} aright'><acronym title='{$total_ctr}%'>".number_format($total_ctr, $pref['ui_percentage_decimals'])."%</acronym></td>
        </tr>
        </table>
        <br /><br />
        ";

} else {
    echo "
        <br /><br /><div class='errormessage'><img class='errormessage' src='" . OX::assetPath() . "/images/info.gif' width='16' height='16' border='0' align='absmiddle'>$strNoStats</div>";
}

// Store preferences
$session['prefs'][$pageName]['hideinactive'] = $hideinactive;
$session['prefs'][$pageName]['listorder'] = $listorder;
$session['prefs'][$pageName]['nodes'] = implode (",", $aNodes);
$session['prefs'][$pageName]['orderdirection'] = $orderdirection;
$session['prefs'][$pageName]['day'] = $day;
$session['prefs'][$pageName]['howLong'] = $howLong;
$session['prefs'][$pageName]['hour'] = $hour;
$session['prefs']['GLOBALS']['period_preset'] = $period_preset;
$session['prefs']['GLOBALS']['period_start'] = $period_start;
$session['prefs']['GLOBALS']['period_end'] = $period_end;
phpAds_SessionDataStore();

// Display page footer
phpAds_PageFooter();

function _scGetHtmlHeaderColumn($title, $name, $pageName, $entityIds, $listorder, $orderdirection)
{
    $entity = _getEntityString($entityIds);
    $img = '';
    $dir = '';
    if ($listorder == $name) {
        if (($orderdirection == '') || ($orderdirection == 'down')) {
            $img = "<img src='" . OX::assetPath() . "/images/caret-ds.gif' border='0' alt='' title=''>";
        } else {
            $img = "<img src='" . OX::assetPath() . "/images/caret-u.gif' border='0' alt='' title=''>";
            $dir = '&orderdirection=down';
        }
    }
    return "<b><a href='$pageName?{$entity}listorder={$name}{$dir}'>{$title}{$img}</a></b>";
}

function numeric_cmp_ctr($a, $b) {
    if ($a['ctr'] == $b['ctr']) return 0;
    return ($a['ctr'] < $b['ctr']) ? -1 : 1;
}

?>
